# will be enabled once I understand how this works and how to eliminate unnecessary errors on the internal
# methods.

#use Test::More;
#eval "use Test::Pod::Coverage 0.08";
#plan skip_all => "Test::Pod::Coverage 0.08 required for testing POD coverage" if $@;
#all_pod_coverage_ok();
use Test::More tests => 1;
ok(1);

